changeset 88:2c26a72ce357

Merge with main
author Patrick Mezard <pmezard@gmail.com>
date Fri, 02 Jan 2009 17:38:16 +0100
parents 67003e27eb79 (diff) 54afa0660a0d (current diff)
children e0b6f2cf99e1
files forest.py
diffstat 1 files changed, 4 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/forest.py	Sat Oct 25 14:54:54 2008 +0200
+++ b/forest.py	Fri Jan 02 17:38:16 2009 +0100
@@ -63,14 +63,13 @@
 # For backwards compatibility, we need the following function definition.
 # If we didn't want that, we'd have just written:
 #     from mercurial.commands import 
-def findcmd(ui, cmd, table):
-    """Find and execute mercurial.*.findcmd(ui, cmd[, table])."""
+def findcmd(ui, cmd, table, strict=True):
+    """Find and execute mercurial.*.findcmd([ui,] cmd[, table, strict])."""
     try:
-        # ui argument was removed as of b4c035057d34
-        return findcmd.findcmd(cmd, table)
+        return findcmd.findcmd(cmd=cmd, table=table, strict=strict)
     except TypeError:
         try:
-            return findcmd.findcmd(ui, cmd, table)
+            return findcmd.findcmd(ui=ui, cmd=cmd, table=table)
         except TypeError:
             return findcmd.findcmd(ui, cmd)
 try: